@@ -3,6 +3,21 @@ class str:
     def __init__(self, jsobject):
         self.jsobject = jsobject
 
+    def __repr__(self):
+        return self
+
+    def join(self, objects):
+        L = len(objects)
+        if not L:
+            return ""
+        out = objects[0]
+        index = 1
+        while index < L:
+            obj = objects[index]
+            out = out + self + obj
+            index += 1
+        return out
+
     def __add__(self, other):
         a = self.jsobject
         b = other.jsobject
